@@ -21,7 +21,7 @@
 #'   \item{activity_destination}{\code{factor}. The type of activity at the destination location (e.g., 'home', 'other'). \strong{Note:} Only available for district level data.}
 #'   \item{residence_province_ine_code}{\code{factor}. The province of residence for the group of individual making the trip, encoded according to the INE classification. \strong{Note:} Only available for district level data.}
 #'   \item{residence_province_name}{\code{factor}. The province of residence for the group of individuals making the trip (e.g., 'Cuenca', 'Girona'). \strong{Note:} Only available for district level data.}
-#'   \item{time_slot}{\code{integer}. The time slot (the hour of the day) during which the trip started, represented as an integer (e.g., 0, 1, 2).}
+#'   \item{hour}{\code{integer}. The time slot (the hour of the day) during which the trip started, represented as an integer (e.g., 0, 1, 2).}
 #'   \item{distance}{\code{factor}. The distance category of the trip, represented as a code (e.g., '002-005' for 2-5 km).}
 #'   \item{n_trips}{\code{double}. The number of trips taken within the specified time slot and distance.}
 #'   \item{trips_total_length_km}{\code{double}. The total length of all trips in kilometers for the specified time slot and distance.}
@@ -532,7 +532,7 @@ spod_sql_where_dates <- function(dates) {
 spod_duckdb_limit_resources <- function(
   con,
   max_mem_gb = max(4, spod_available_ram() - 4),
-  max_n_cpu = parallelly::availableCores() - 1
+  max_n_cpu = max(1, parallelly::availableCores() - 1)
 ) {
   DBI::dbExecute(
     con,
